@@ -1,5 +1,6 @@
 package DBSchema::Sample;
 
+
 use 5.006;
 use strict;
 use warnings;
@@ -26,7 +27,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(load
 	
 );
-our $VERSION = '1.6';
+our $VERSION = '1.7';
 
 
 # Preloaded methods go here.
@@ -215,16 +216,6 @@ sub app_handle {
   my $attr = { RaiseError => 1, PrintError => 1 } ;
   my $class = __PACKAGE__;
 
-  warn "
-  DBIx::AnyDBD->connect
-	(
-	 $c->{dsn},
-	 $c->{user},
-	 $c->{pass},
-	 $attr,
-	 $class # The one difference between DBI and DBIx::AnyDBD
-	);
-";
 
   DBIx::AnyDBD->connect
 	(
@@ -300,15 +291,7 @@ creating a realistic schema and populating it with sensible data.
 
  load()
 
-=head1 SCHEMA DESCRIPTION
-
-=begin html
-
-<img src=http://dbschema-sample.berlios.de/schema.jpg>
-
-=end   html
-
-
+=head1 SCHEMA DESCRIPTON
 
 =head2 authors =1:n=> titleauthors
 
@@ -337,12 +320,6 @@ varying royalties based on the total volume sold.
 
 =head3 Therefore titles =n:n=> sales
 
-=head1 SUPPORT
-
-Development and support of this module is handled at
-
-L<http://dbschema-sample.berlios.de>
-
 =head1 AUTHOR
 
 T. M. Brannon, tbone@cpan.org
